Learn R Programming

peruflorads43 (version 0.2.3)

direct_match_species_within_genus_helper: Direct Match Species within Genus

Description

This function performs a direct match of specific epithets within an already matched genus from the list of threatened species in the database.

Usage

direct_match_species_within_genus_helper(df, target_df)

Value

A tibble with an additional logical column indicating whether the specific epithet was successfully matched within the matched genus (`TRUE`) or not (`FALSE`).

Arguments

df

A tibble containing the species data to be matched.

target_df

A tibble representing the threatened species database containing the reference list of threatened species.