Extracts and consolidates ambiguous match attributes from multiple objects. This prevents attribute loss during dplyr transformations.
.backup_ambiguous_attrs(...)A named list with consolidated ambiguous match attributes:
Tibble with ambiguous genus matches
Tibble with ambiguous species matches
Tibble with ambiguous infraspecies level 1 matches
Tibble with ambiguous infraspecies level 2 matches
One or more data frames or tibbles that may contain ambiguous match attributes