This function performs a direct match of genus names against the genus names listed in the threatened species database.
genus_match(df, target_df = NULL)A tibble with an additional logical column genus_match indicating whether the genus was successfully matched (`TRUE`) or not (`FALSE`).
A tibble containing the genus names to be matched.
A tibble representing the threatened species database containing the reference list of threatened species.